Model Code:

.. literalinclude:: /../../cis_interface/examples/formatted_io3/src/formatted_io3_modelA.py
   :language: python
   :linenos:

.. literalinclude:: /../../cis_interface/examples/formatted_io3/src/formatted_io3_modelB.py
   :language: python
   :linenos:


(`Example in other languages <examples/formatted_io3.html>`__)
